<?php

namespace Includes\Controllers\Api;

use Includes\baseClasses\STBase;
use WP_REST_Response;
use WP_REST_Server;
use WP_Query;
class STStreamitController extends STBase {

	public $module = 'streamit';

	public $nameSpace;

	function __construct() {

		$this->nameSpace = STREAMIT_API_NAMESPACE;

		add_action( 'rest_api_init', function () {

			register_rest_route( $this->nameSpace . '/api/v1/' . $this->module, '/search-list', array(
				'methods'             => WP_REST_Server::ALLMETHODS,
				'callback'            => [ $this, 'streamit_search_list' ],
				'permission_callback' => '__return_true'
			) );

			register_rest_route( $this->nameSpace . '/api/v1/' . $this->module, '/like-movie-show', array(
				'methods'             => WP_REST_Server::ALLMETHODS,
				'callback'            => [ $this, 'streamit_like_dislike' ],
				'permission_callback' => '__return_true'
			) );

			register_rest_route( $this->nameSpace . '/api/v1/' . $this->module, '/add-remove-watchlist', array(
				'methods'             => WP_REST_Server::ALLMETHODS,
				'callback'            => [ $this, 'streamit_add_remove_watchlist' ],
				'permission_callback' => '__return_true'
			) );

			register_rest_route( $this->nameSpace . '/api/v1/' . $this->module, '/change-password', array(
				'methods'             => WP_REST_Server::ALLMETHODS,
				'callback'            => [ $this, 'streamit_change_password' ],
				'permission_callback' => '__return_true'
			) );

			register_rest_route( $this->nameSpace . '/api/v1/' . $this->module, '/forgot-password', array(
				'methods'             => WP_REST_Server::ALLMETHODS,
				'callback'            => [ $this, 'streamit_forgot_password' ],
				'permission_callback' => '__return_true'
			) );

			register_rest_route( $this->nameSpace . '/api/v1/' . $this->module, '/get-watchlist', array(
				'methods'             => WP_REST_Server::ALLMETHODS,
				'callback'            => [ $this, 'streamit_get_watchlist' ],
				'permission_callback' => '__return_true'
			) );

			register_rest_route( $this->nameSpace . '/api/v1/' . $this->module, '/update-profile', array(
				'methods'             => WP_REST_Server::ALLMETHODS,
				'callback'            => [ $this, 'streamit_update_profile' ],
				'permission_callback' => '__return_true'
			) );

			register_rest_route( $this->nameSpace . '/api/v1/' . $this->module, '/get-dashboard', array(
				'methods'             => WP_REST_Server::ALLMETHODS,
				'callback'            => [ $this, 'streamit_get_dashboard' ],
				'permission_callback' => '__return_true'
			) );

			register_rest_route( $this->nameSpace . '/api/v1/' . $this->module, '/slider-view-all', array(
				'methods'             => WP_REST_Server::ALLMETHODS,
				'callback'            => [ $this, 'streamit_slider_view_all' ],
				'permission_callback' => '__return_true'
			) );
		} );
	}

	public function streamit_search_list($request) {

		$parameters = $request->get_params();
	
		$array = array();
		$masterarray = array();
	
		$args = array();
		
		$parameters['post_type'] = [ 'movie','tv_show', 'episode' ];
		$user_data = array_key_exists( "user_id", $parameters );
		
		if(!$user_data){
			$parameters['user_id'] = null;
		}
		$args = streamit_post_args($parameters);
	
		$wp_query = new WP_Query($args);
	
		$total = $wp_query->found_posts;
		$num_pages = 1;
		$num_pages = $wp_query->max_num_pages;
	
		$i = 1;
		while ($wp_query->have_posts()) {
			$wp_query->the_post();
			$array = get_movie_show_episode_list(get_the_ID(), $num_pages, $i ,$parameters['user_id']);
			array_push($masterarray, $array);
			$i++;
		}
	
		return comman_list_response($masterarray);  
	
	}

	public function streamit_like_dislike($request) {
		global $wpdb;
		$table_name = $wpdb->prefix.'ulike';
		$table_ulike_meta = $wpdb->prefix.'ulike_meta';
		$data = stValidationToken();

		if (!$data['status']) {
			return comman_custom_response($data,401);
		}

		$parameters = $request->get_params();
		
		$post_id = $parameters['post_id'];
		$user_id = $data['user_id'];
	
		$post = get_post($post_id);
	
		if($post == null){
			return comman_message_response( __('Not found') , 422 );
		}
	
		$post_status = $wpdb->get_row("SELECT * FROM {$table_name} WHERE `user_id`=" . $user_id . " AND `post_id` =" . $post_id . "", OBJECT);
	
		$ulike_post_meta = $wpdb->get_row("SELECT * FROM {$table_ulike_meta} WHERE `item_id`=" . $post_id . " AND `meta_key`='count_distinct_like'", OBJECT);
		
		if ( $ulike_post_meta == null ) {
			$wpdb->insert( $table_ulike_meta , array(
				"item_id"		=> $post_id,
				"meta_group" 	=> 'post',
				"meta_key"      => 'count_distinct_like',
				"meta_value"	=> 0
			));
		}
		$message = null;
		$isLiked = null;
		if($post_status != null) {

			if($post_status->status == 'like'){
				$wpdb->query("UPDATE $table_ulike_meta SET `meta_value`= meta_value - 1 WHERE `item_id` =" . $post_id . " AND  `meta_key`='count_distinct_like' AND `meta_group` = 'post' ");
				$wpdb->query("UPDATE $table_name SET `status`='unlike' WHERE `user_id`=" . $user_id . " AND `post_id` =" . $post_id . "");
				$isLiked = false;
				$message = __("You unliked this");
			}

			if($post_status->status == 'unlike'){
				$wpdb->query("UPDATE $table_ulike_meta SET `meta_value`= meta_value + 1 WHERE `item_id` =" . $post_id . " AND  `meta_key`='count_distinct_like' AND `meta_group` = 'post' ");
				$wpdb->query("UPDATE $table_name SET `status`='like' WHERE `user_id`=" . $user_id . " AND `post_id` =" . $post_id . "");
				$isLiked = true;
				$message = __("You liked this");
			}
		}else{
			$wpdb->insert( $table_name , array(
				'user_id'   => $user_id,
				'post_id'   => $post_id,
				'date_time'	=> wp_date('Y-m-d H:i:s'),
				'status'    => 'like'
			)
			);
			$wpdb->query("UPDATE $table_ulike_meta SET `meta_value`= meta_value + 1 WHERE `item_id` =" . $post_id . " AND  `meta_key`='count_distinct_like' AND `meta_group` = 'post' ");
			$isLiked = true;
			$message = __("You liked this");
		}
		$resArray = array('is_added' => $isLiked, 'message' => $message);
		return comman_custom_response( $resArray );
	}

	public function streamit_add_remove_watchlist($request) {

		$data = stValidationToken();

		if (!$data['status']) {
			return comman_custom_response($data,401);
		}

		$parameters = $request->get_params();
		
		$post_id = $parameters['post_id'];
		$user_id = $data['user_id'];
	
	
		$post = get_post($post_id);
	
		if($post == null){
			return comman_message_response( __('Not found') , 422 );
		}
	
		$watch_list = streamit_watchlist($post_id ,$user_id);
	
		$post_watchlist = get_user_meta( $user_id, '_user_watchlist', true );
	
		$watchlist_array = explode(', ', $post_watchlist);
		$isAdded= false;
	
		if(!$watch_list){
			// Check if the likers metabox already has a value to determine if the new entry has to be prefixed with a comma or not
	
			if(!empty($post_watchlist)){
				$newvalue = $post_watchlist .', '. $post_id;
			}else{
				$newvalue = $post_id;
			}
	
			update_user_meta($user_id, '_user_watchlist', $newvalue, $post_watchlist);
			$message  = __("Added into watchlist");
	
			$isAdded = true;
		} else {
			$key = array_search($post_id, $watchlist_array);

			unset($watchlist_array[$key]);
			
			update_user_meta($user_id, '_user_watchlist', implode(", ", $watchlist_array), $post_watchlist);
	
			$message  = __("Remove from watchlist");
		
		}    
	
		$resArray = array('is_added' => $isAdded, 'message' => $message);
		return comman_custom_response($resArray);
	}

	public function streamit_change_password($request) {

		$data = stValidationToken();

		if (!$data['status']) {
			return comman_custom_response($data,401);
		}

		$parameters = $request->get_params();

		$userdata = get_user_by('ID', $data['user_id']);
		
		if ($userdata == null) {
			
			if ($userdata == null) {
				$message = __('User not found');
				return comman_message_response($message,422);
			}
		}

		$status_code = 200;

		if (wp_check_password($parameters['old_password'], $userdata->data->user_pass)){
			wp_set_password($parameters['new_password'], $userdata->ID);
			$message = __("Password has been changed successfully");
		}else {
			$status_code = 422;
			$message = __("Old password is invalid");
		}
		return comman_message_response($message,$status_code);
	}

	public function streamit_forgot_password($request) {
		$parameters = $request->get_params();
		$email = $parameters['email'];
		
		$user = get_user_by('email', $email);
		$message = null;
		$status_code = null;
		
		if($user) {      

			$title = 'New Password';
            $password = stGenerateString();
            $message = '<label><b>Hello,</b></label>';
            $message.= '<p>Your recently requested to reset your password. Here is the new password for your App</p>';
            $message.='<p><b>New Password </b> : '.$password.'</p>';
            $message.='<p>Thanks,</p>';

            $headers = "MIME-Version: 1.0" . "\r\n";
            $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";
			$is_sent_wp_mail = wp_mail($email,$title,$message,$headers);

            if($is_sent_wp_mail) {
				wp_set_password( $password, $user->ID);
				$message = __('Password has been sent successfully to your email address.');
				$status_code = 200;
			} elseif (mail( $email, $title, $message, $headers )) {
				wp_set_password( $password, $user->ID);
				$message = __('Password has been sent successfully to your email address.');
				$status_code = 200;
			} else {
				$message = __('Email not sent');
				$status_code = 422;
			}
		} else {
			$message = __('User not found with this email address');
			$status_code = 422;
		}
		return comman_message_response($message,$status_code);
	}

	public function streamit_get_watchlist($request) {
		$data = stValidationToken();

		if (!$data['status']) {
			return comman_custom_response($data,401);
		}

		$parameters = $request->get_params();
		$userdata = get_user_by('ID', $data['user_id']);
		
		if ($userdata == null) {
			
			if ($userdata == null) {
				$message = __('User not found');
				return comman_message_response($message,422);
			}
		}

		$post_watchlist = get_user_meta( $data['user_id'] , '_user_watchlist', true );

		$response = [];
		if(!empty($post_watchlist) && $post_watchlist != null) {

			$watchlist_array = explode(', ', $post_watchlist);

			if(count($watchlist_array) > 0) {
				foreach( $watchlist_array as $post ) {
					$response[] = streamit_movie_video_detail_helper($post,$data['user_id']);
				}
			}
		}

		return comman_list_response($response);
	}

	public function streamit_update_profile($request) {
		$data = stValidationToken();

		if (!$data['status']) {
			return comman_custom_response($data,401);
		}

		$parameters = $request->get_params();
		$userdata = get_user_by('ID', $data['user_id']);
		
		if ($userdata == null) {
			
			if ($userdata == null) {
				$message = __('User not found');
				return comman_message_response($message,422);
			}
		}
		$message = __("Profile has been updated successfully");
		$data = array();
		wp_update_user([
			'ID' => $userdata->ID,
			'first_name' => $parameters['first_name'],
			'last_name' => $parameters['last_name']
		]);
		
		$data = [
			'first_name' => get_user_meta($userdata->ID , 'first_name' ,true),
			'last_name' => get_user_meta($userdata->ID , 'last_name' ,true)
		];
		if( isset($parameters['profile_image']) && $parameters['profile_image'] != null ){

			$profile_image = $parameters['profile_image']; 
			$type      = explode(';', $profile_image)[0];
			$extension = explode('/', $type)[1];

			// Upload dir.
			$upload_dir  = wp_upload_dir();
			$upload_path = str_replace( '/', DIRECTORY_SEPARATOR, $upload_dir['path'] ) . DIRECTORY_SEPARATOR;
		
			$img             = str_replace( 'data:image/'.$extension.';base64,', '', $profile_image );
			$img             = str_replace( ' ', '+', $img );
			$decoded         = base64_decode( $img );
			$filename        = '.'.$extension;
			$file_type       = 'image/'.$extension;
			$hashed_filename = md5( $filename . microtime() ) . $filename;
		
			// Save the image in the uploads directory.
			$upload_file = file_put_contents( $upload_path . $hashed_filename, $decoded );
		
			$attachment = array(
				'post_mime_type' => $file_type,
				'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $hashed_filename ) ),
				'post_content'   => '',
				'post_status'    => 'inherit',
				'guid'           => $upload_dir['url'] . '/' . basename( $hashed_filename )
			);
		
			$attach_id = wp_insert_attachment( $attachment, $upload_dir['path'] . '/' . $hashed_filename );
		
			// Regenerate Thumbnail
			global $wpdb;
			$images = $wpdb->get_results( "SELECT ID FROM $wpdb->posts WHERE post_type = 'attachment' AND post_mime_type LIKE 'image/%' AND ID ='$attach_id'" );
		
			foreach ( $images as $image ) {
				$id = $image->ID;
				$fullsizepath = get_attached_file( $id );
		
				if ( false === $fullsizepath || !file_exists($fullsizepath) )
					return;

			}
			$url = wp_get_attachment_url( $attach_id );
	
			$update = update_user_meta( $userdata->ID, 'streamit_profile_image', $url );

			if(!is_wp_error($update))
			{
				$img = get_user_meta( $userdata->ID, 'streamit_profile_image' ) ;  
				$data['profile_image'] = $img[0];
			}
			
		}
		$data['message'] = $message;
		
		return comman_custom_response($data);
	}

	public function streamit_get_dashboard($request) {
	
		$parameters = $request->get_params();
	
		$masterarray = array();

		$user_data = array_key_exists( "user_id", $parameters );
		
		if(!$user_data){
			$parameters['user_id'] = null;
		}

		$type = $parameters['type'];
			$home_option = get_option('streamit_app_'.$type);

			if( !empty($home_option) ) {
				if( !empty($home_option['banner']) && count($home_option['banner']) > 0 ) {
					$banner_data = [];
					foreach( $home_option['banner'] as $banner ) {
						$bdata = streamit_movie_video_detail_helper($banner['show'],$parameters['user_id']);
						
						if( !empty($bdata)){
							$banner_image = wp_get_attachment_image_src($banner['attachment'],[768, 432]);
					
							if ( !(empty($banner_image)) && $banner_image[0]) {
								$bdata['attachment'] = $banner_image[0];
							} else {
								$bdata['attachment'] = null;
							}
							$banner_data[] = $bdata;
						}
					}
					$masterarray['banner'] = $banner_data;
				}

				if( !empty($home_option['sliders']) && count($home_option['sliders']) > 0 ) {
					$slider_data = [];
					foreach( $home_option['sliders'] as $sliders ) {
						$sliderdata['title'] = $sliders['title'];
						$sliderdata['view_all'] = (bool)$sliders['view_all'];
											
						if($sliders['filter'] != 'upcoming'){
							$arg['posts_per_page'] = (!empty($parameters['posts_per_page']) && isset($parameters['posts_per_page'])) ? $parameters['posts_per_page'] : 6;
							$arg['paged'] =  (!empty($parameters['paged']) && isset($parameters['paged'])) ? $parameters['paged'] : 1;
						}else {
							$arg['posts_per_page'] = -1;
						}
						$arg['post_status'] = 'publish';
						$arg['post_type'] = ( $type == 'home' ) ? ['movie', 'tv_show'] : $type;

						$taxargs = array();
						$gener_type = '';
						
						$genre = $sliders['genre'];
						$tag = $sliders['tag'] ;

                        if(!empty($type))
                        {
                            $gener_type = $type.'_genre';
                            $tag_type = $type.'_tag';
                            
							if($type === 'home')
                            {
								if(!empty($genre))
								{
									$tax_query_movie['taxonomy'] = 'movie_genre';
									$tax_query_movie['field'] = 'term_id';
									$tax_query_movie['terms'] = $genre;
									$tax_query_movie['operator'] = 'IN';
									array_push($taxargs, $tax_query_movie);
									$tax_query_tvshow['taxonomy'] = 'tv_show_genre';
									$tax_query_tvshow['field'] = 'term_id';
									$tax_query_tvshow['terms'] = $genre;
									$tax_query_tvshow['operator'] = 'IN';
									array_push($taxargs, $tax_query_tvshow);
								}
								if(!empty($tag))
								{
									$tax_query_mtag['taxonomy'] = 'movie_tag';
									$tax_query_mtag['field'] = 'term_id';
									$tax_query_mtag['terms'] = $tag;
									$tax_query_mtag['operator'] = 'IN';
									array_push($taxargs, $tax_query_mtag);
									$tax_query_stag['taxonomy'] = 'tv_show_tag';
									$tax_query_stag['field'] = 'term_id';
									$tax_query_stag['terms'] = $tag;
									$tax_query_stag['operator'] = 'IN';
									array_push($taxargs, $tax_query_stag);
								}
                            }
                        }
                        if(!empty($genre) && !empty($gener_type) && $type !== 'home')
                        {
                            $tax_query['taxonomy'] = $gener_type;
                            $tax_query['field'] = 'term_id';
                            $tax_query['terms'] = $genre;
                            $tax_query['operator'] = 'IN';
                            array_push($taxargs, $tax_query);
                        }
                        if(!empty($tag)&& !empty($tag_type) && $type !== 'home')
                        {
                            $tax_query['taxonomy'] = $tag_type;
                            $tax_query['field'] = 'term_id';
                            $tax_query['terms'] = $tag;
                            $tax_query['operator'] = 'IN';
                            array_push($taxargs, $tax_query);
                        
                        }
                        if(!empty($taxargs))
                        {
                            $arg['tax_query'] = $taxargs;
                            $arg['tax_query']['relation'] = 'OR';
						}

						$movie_show_data = new WP_Query( $arg );
						if($movie_show_data->have_posts()) {
							$sdata = [];
							while($movie_show_data->have_posts()) {
								$movie_show_data->the_post();
								
								$slider = streamit_movie_video_detail_helper(get_the_ID(),$parameters['user_id']);
								if($sliders['filter'] == 'upcoming' && ($slider['name_upcoming'] == '' || $slider['name_upcoming'] ==  null)){
								 	continue;
								}
								$sdata[] = $slider;
								
							}
						}
						$sliderdata['data'] = array_slice($sdata,0,6);
						$slider_data[] = $sliderdata;
					}
					$masterarray['sliders'] = $slider_data;
				}
			} else {
				$masterarray['banner'] = [];
				$masterarray['sliders'] = [];
			}

		return comman_custom_response ($masterarray);
	}

	public function streamit_slider_view_all($request) {
	
		$parameters = $request->get_params();
	
		$masterarray = array();

		$user_data = array_key_exists( "user_id", $parameters );
		$slider_data = [];
		if(!$user_data){
			$parameters['user_id'] = null;
		}

		$type = $parameters['type'];
		$slider_id = (!empty($parameters['slider_id']) && isset($parameters['slider_id'])) ? $parameters['slider_id'] : 0;
			$home_option = get_option('streamit_app_'.$type);

			if( !empty($home_option) ) {

				if( !empty($home_option['sliders']) && count($home_option['sliders']) >= $slider_id ) {
					
					$sliders = $home_option['sliders'][$slider_id];
					// foreach( $home_option['sliders'] as $sliders ) {
						$sliderdata['title'] = $sliders['title'];
						$genre = $sliders['genre'];
						$tag = $sliders['tag'] ;
						
						if($sliders['filter'] != 'upcoming'){
							$arg['posts_per_page'] = (!empty($parameters['posts_per_page']) && isset($parameters['posts_per_page'])) ? $parameters['posts_per_page'] : 20;
							$arg['paged'] =  (!empty($parameters['paged']) && isset($parameters['paged'])) ? $parameters['paged'] : 1;
						}else {
							$arg['posts_per_page'] = -1;
						}
						$arg['post_status'] = 'publish';
						$arg['post_type'] = ( $type == 'home' ) ? ['movie', 'tv_show'] : $type;

						if( $sliders['filter'] == 'latest' ){
							$arg['order'] = 'DESC';
							$arg['orderby'] = 'publish_date';
						}

						$taxargs = array();
                        $gener_type = '';
                        if(!empty($type))
                        {
                            $gener_type = $type.'_genre';
                            $tag_type = $type.'_tag';
                            
							if($type === 'home')
                            {
								if(!empty($genre))
								{
									$tax_query_movie['taxonomy'] = 'movie_genre';
									$tax_query_movie['field'] = 'term_id';
									$tax_query_movie['terms'] = $genre;
									$tax_query_movie['operator'] = 'IN';
									array_push($taxargs, $tax_query_movie);
									$tax_query_tvshow['taxonomy'] = 'tv_show_genre';
									$tax_query_tvshow['field'] = 'term_id';
									$tax_query_tvshow['terms'] = $genre;
									$tax_query_tvshow['operator'] = 'IN';
									array_push($taxargs, $tax_query_tvshow);
								}
								if(!empty($tag))
								{
									$tax_query_mtag['taxonomy'] = 'movie_tag';
									$tax_query_mtag['field'] = 'term_id';
									$tax_query_mtag['terms'] = $tag;
									$tax_query_mtag['operator'] = 'IN';
									array_push($taxargs, $tax_query_mtag);
									$tax_query_stag['taxonomy'] = 'tv_show_tag';
									$tax_query_stag['field'] = 'term_id';
									$tax_query_stag['terms'] = $tag;
									$tax_query_stag['operator'] = 'IN';
									array_push($taxargs, $tax_query_stag);
								}
                            }
                        }
                        if(!empty($genre) && !empty($gener_type) && $type !== 'home')
                        {
                            $tax_query['taxonomy'] = $gener_type;
                            $tax_query['field'] = 'term_id';
                            $tax_query['terms'] = $genre;
                            $tax_query['operator'] = 'IN';
                            array_push($taxargs, $tax_query);
                        }
                        if(!empty($tag)&& !empty($tag_type) && $type !== 'home')
                        {
                            $tax_query['taxonomy'] = $tag_type;
                            $tax_query['field'] = 'term_id';
                            $tax_query['terms'] = $tag;
                            $tax_query['operator'] = 'IN';
                            array_push($taxargs, $tax_query);
                        
                        }
                        if(!empty($taxargs))
                        {
                            $arg['tax_query'] = $taxargs;
                            $arg['tax_query']['relation'] = 'OR';
                        }
						$movie_show_data = new WP_Query( $arg );

						if($movie_show_data->have_posts()) {
							$sdata = [];
							while($movie_show_data->have_posts()) {
								$movie_show_data->the_post();
								$slider = streamit_movie_video_detail_helper(get_the_ID(),$parameters['user_id']);
								if($sliders['filter'] == 'upcoming' && ($slider['name_upcoming'] == '' || $slider['name_upcoming'] ==  null)){
								 	continue;
								}
								$sdata[] = $slider;
							}
						}
						$sliderdata['data'] = $sdata;
						$slider_data = $sliderdata;
					// }
				}
			}

		return comman_custom_response ($slider_data);
	}
}