import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:streamit_flutter/screens/account_settings_screen.dart';
import 'package:streamit_flutter/screens/edit_profile_screen.dart';
import 'package:streamit_flutter/screens/help_screen.dart';
import 'package:streamit_flutter/screens/terms_conditions_screen.dart';
import 'package:streamit_flutter/utils/app_localizations.dart';
import 'package:streamit_flutter/utils/app_widgets.dart';
import 'package:streamit_flutter/utils/constants.dart';
import 'package:streamit_flutter/utils/resources/images.dart';
import 'package:streamit_flutter/utils/resources/size.dart';
import 'package:streamit_flutter/utils/widget_extensions.dart';

class MoreFragment extends StatefulWidget {
  static String tag = '/MoreFragment';

  @override
  MoreFragmentState createState() => MoreFragmentState();
}

class MoreFragmentState extends State<MoreFragment> {
  var profileImage = "";
  var userName = "";
  var userEmail = "";
  var isDarkMode = true;

  @override
  void initState() {
    super.initState();
    getUserData();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: toolBarTitle(context, keyString(context, "more")),
        backgroundColor: Theme.of(context).cardColor,
        elevation: 0,
      ),
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Container(
            color: Theme.of(context).cardColor,
            padding: EdgeInsets.only(
                left: spacing_standard_new,
                top: spacing_standard_new,
                right: 12,
                bottom: spacing_standard_new),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                Card(
                  semanticContainer: true,
                  clipBehavior: Clip.antiAliasWithSaveLayer,
                  elevation: spacing_standard_new,
                  margin: EdgeInsets.all(0),
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(80),
                  ),
                  child: networkImage(
                    profileImage,
                    aHeight: 70,
                    aWidth: 70,
                  ),
                ).paddingRight(spacing_standard_new),
                Expanded(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      text(context, userName,
                          fontSize: ts_extra_normal,
                          fontFamily: font_bold,
                          textColor: Theme.of(context).textTheme.headline6.color),
                      text(context, userEmail,
                          fontSize: ts_normal,
                          fontFamily: font_medium,
                          textColor: Theme.of(context).textTheme.subtitle2.color)
                    ],
                  ),
                ),
                Image.asset(
                  ic_edit_profile,
                  width: 20,
                  height: 20,
                  color: Theme.of(context).primaryColor,
                ).paddingAll(spacing_control).onTap(() {
                  launchScreen(context, EditProfileScreen.tag);
                })
              ],
            ),
          ),
          Expanded(
            child: SingleChildScrollView(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  itemSubTitle(context, keyString(context, "general_settings"),
                          colorThird: false)
                      .paddingOnly(
                          left: spacing_standard_new,
                          right: spacing_standard_new,
                          top: 12,
                          bottom: 12),
                  subType(context, "account_settings", () {
                    launchScreen(context, AccountSettingsScreen.tag);
                  }, ic_settings),
                  Row(
                    children: <Widget>[
                      Image.asset(
                        ic_dark_mode,
                        width: 20,
                        height: 20,
                        color: Theme.of(context).textTheme.headline6.color,
                      ).paddingRight(spacing_standard),
                      Expanded(
                          child: itemTitle(
                              context, keyString(context, "dark_mode"))),
                      Theme(
                        data: Theme.of(context).copyWith(
                          unselectedWidgetColor: Theme.of(context).primaryColor,
                        ),
                        child: Checkbox(
                          activeColor: Theme.of(context).primaryColor,
                          checkColor: Theme.of(context).cardColor,
                          value: isDarkMode,
                          onChanged: (value) {
                            setState(() {
                              isDarkMode = value;
                            });
                          },
                        ),
                      )
                    ],
                  )
                      .paddingOnly(
                          left: spacing_standard_new,
                          right: spacing_control,
                          top: spacing_control,
                          bottom: spacing_control)
                      .onTap(() {
                    setState(() {
                      isDarkMode = !isDarkMode;
                    });
                  }),
                  subType(context, "language", () {}, ic_language),
                  subType(context, "help", () {
                    launchScreen(context, HelpScreen.tag);
                  }, ic_help),
                  itemSubTitle(context, keyString(context, "terms"))
                      .paddingOnly(
                          left: spacing_standard_new,
                          right: 12,
                          top: spacing_standard_new,
                          bottom: spacing_control),
                  subType(context, "terms_conditions", () {
                    launchScreen(context, TermsConditionsScreen.tag);
                  }, null),
                  subType(context, "privacy_policy", () {
                    launchScreen(context, TermsConditionsScreen.tag);
                  }, null),
                  subType(context, "logout", () {}, null),
                ],
              ).paddingBottom(spacing_large),
            ),
          )
        ],
      ),
    );
  }

  void getUserData() {
    setState(() {
      profileImage = "assets/items/actors/01.jpg";
      userName = "Vicotria Becks";
      userEmail = "vicotriabecks@gmail.com";
    });
  }
}
