import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:streamit_flutter/models/response.dart';
import 'package:streamit_flutter/screens/movie_detail_screen_2.dart';
import 'package:streamit_flutter/screens/view_all_movies_screen.dart';
import 'package:streamit_flutter/utils/app_localizations.dart';
import 'package:streamit_flutter/utils/app_widgets.dart';
import 'package:streamit_flutter/utils/data_generator.dart';
import 'package:streamit_flutter/utils/resources/size.dart';
import 'package:streamit_flutter/utils/widget_extensions.dart';

// ignore: must_be_immutable
class HomeCategoryFragment extends StatefulWidget {
  static String tag = '/SubHomeFragment';
  var type;

  HomeCategoryFragment({this.type});

  @override
  HomeCategoryFragmentState createState() => HomeCategoryFragmentState();
}

class HomeCategoryFragmentState extends State<HomeCategoryFragment> {
  var mSliderList = List<HomeSlider>();
  var mMovieList = List<Movie>();
  var mCinemaMovieList = List<Movie>();
  var mcontinueList = List<Movie>();
  var mTrendingMuviList = List<Movie>();
  var mMadeForYouList = List<Movie>();
  bool isLoading = false;

  showLoading(bool show) {
    setState(() {
      isLoading = show;
    });
  }

  @override
  void initState() {
    super.initState();
    getData();
  }

  getData() {
    setState(() {
      mSliderList.addAll(getSliders());
      mMovieList.addAll(getUpcomingMovie());
      mCinemaMovieList.addAll(getTop10());
      mcontinueList.addAll(getContinueMovies());
      mTrendingMuviList.addAll(getTrendingOnMovie());
      mMadeForYouList.addAll(getMadeForYouMovie());
    });
  }

  @override
  Widget build(BuildContext context) {
    var slider =
        mSliderList.isNotEmpty ? HomeSliderWidget(mSliderList) : Container();
    var madeForYouSlider = mMadeForYouList.isNotEmpty
        ? ItemHorizontalList(
            mMadeForYouList,
            isMovie: false,
          )
        : Container();
    var popularMovieList = mMovieList.isNotEmpty
        ? ItemHorizontalList(
            mMovieList,
            isMovie: true,
          )
        : Container();
    var trendingMovieList = mTrendingMuviList.isNotEmpty
        ? ItemHorizontalList(
            mTrendingMuviList,
            isMovie: false,
          )
        : Container();
    var newCinemaList = mCinemaMovieList.isNotEmpty
        ? ItemHorizontalList(
            mCinemaMovieList,
            isMovie: true,
          )
        : Container();
    var continueWatchingList = mcontinueList.isNotEmpty
        ? ItemProgressHorizontalList(
            mcontinueList,
          )
        : Container();
    return Scaffold(
      body: Stack(
        children: <Widget>[
          SingleChildScrollView(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                slider.paddingTop(spacing_standard_new),
                headingWidViewAll(
                    context, keyString(context, "upcoming_movies"), () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (context) => ViewAllMovieScreen(
                              title: keyString(context, "upcoming_movies"))));
                }).paddingAll(spacing_standard_new),
                popularMovieList,
                headingText(context, keyString(context, "continue_watching"))
                    .paddingOnly(
                        left: spacing_standard_new,
                        right: spacing_standard_new,
                        top: 12,
                        bottom: spacing_standard_new),
                continueWatchingList,
                headingWidViewAll(context, keyString(context, "top_10"), () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (context) => ViewAllMovieScreen(
                              title: keyString(context, "top_10"))));
                }).paddingAll(spacing_standard_new),
                newCinemaList,
                headingText(context, keyString(context, "suggested_for_you"))
                    .onTap(() {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (context) => ViewAllMovieScreen(
                              title: keyString(context, "suggested_for_you"))));
                }).paddingAll(spacing_standard_new),
                madeForYouSlider,
                headingWidViewAll(context, keyString(context, "trending"), () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (context) => ViewAllMovieScreen(
                              title: keyString(context, "trending"))));
                }).paddingAll(spacing_standard_new),
                trendingMovieList.paddingBottom(spacing_standard_new)
              ],
            ),
          ),
          Center(child: loadingWidgetMaker().visible(isLoading))
        ],
      ),
    );
  }
}

// ignore: must_be_immutable
class HomeSliderWidget extends StatelessWidget {
  List<HomeSlider> mSliderList;

  HomeSliderWidget(this.mSliderList);

  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    final Size cardSize = Size(width, width / 1.8);
    return Container(
      height: cardSize.height,
      child: PageView.builder(
        itemCount: mSliderList.length,
        itemBuilder: (context, index) {
          HomeSlider slider = mSliderList[index];
          return Container(
            width: MediaQuery.of(context).size.width,
            height: cardSize.height,
            child: Card(
              semanticContainer: true,
              clipBehavior: Clip.antiAliasWithSaveLayer,
              elevation: 0,
              margin: EdgeInsets.all(0),
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(spacing_control),
              ),
              child: Stack(
                alignment: Alignment.bottomLeft,
                children: <Widget>[
                  networkImage(slider.slideImage,
                      aWidth: cardSize.width,
                      aHeight: cardSize.height,
                      fit: BoxFit.cover),
                  Container(
                    decoration: BoxDecoration(
                        gradient: new LinearGradient(
                            colors: [
                          Colors.transparent,
                          Theme.of(context).scaffoldBackgroundColor,
                        ],
                            stops: [
                          0.0,
                          1.0
                        ],
                            begin: FractionalOffset.topCenter,
                            end: FractionalOffset.bottomCenter,
                            tileMode: TileMode.repeated)),
                    child: Column(
                      mainAxisSize: MainAxisSize.min,
                      mainAxisAlignment: MainAxisAlignment.end,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: <Widget>[
                        itemTitle(context, slider.title, fontSize: ts_large),
                        Row(
                          children: <Widget>[
                            hdWidget(context)
                                .paddingRight(spacing_standard)
                                .visible(slider.isHD),
                            itemSubTitle(context, "2018"),
                            itemSubTitle(context, "17+")
                                .paddingLeft(spacing_standard)
                          ],
                        ).paddingTop(spacing_control_half)
                      ],
                    ).paddingOnly(
                        left: spacing_standard_new,
                        bottom: spacing_standard_new,
                        top: 50),
                  )
                ],
              ),
            ).paddingBottom(spacing_control),
          ).onTap(() {
            Navigator.push(
                context,
                MaterialPageRoute(
                    builder: (context) => MovieDetail2Screen(title: "Action")));
          });
        },
        scrollDirection: Axis.horizontal,
      ),
    );
  }
}
