import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:provider/provider.dart';
import 'package:streamit_flutter/screens/account_settings_screen.dart';
import 'package:streamit_flutter/screens/edit_profile_screen.dart';
import 'package:streamit_flutter/screens/faq_screen.dart';
import 'package:streamit_flutter/screens/help_screen.dart';
import 'package:streamit_flutter/screens/home_screen.dart';
import 'package:streamit_flutter/screens/onboarding_screen.dart';
import 'package:streamit_flutter/screens/signin.dart';
import 'package:streamit_flutter/screens/signup.dart';
import 'package:streamit_flutter/screens/splash_screen.dart';
import 'package:streamit_flutter/screens/terms_conditions_screen.dart';
import 'package:streamit_flutter/utils/app_localizations.dart';
import 'package:streamit_flutter/utils/app_state.dart';
import 'package:streamit_flutter/utils/app_theme.dart';

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  SystemChrome.setPreferredOrientations([DeviceOrientation.portraitUp]);
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
        create: (_) => AppState("en", isDarkMode: true),
        child: Consumer<AppState>(builder: (context, provider, builder) {
          return MaterialApp(
            debugShowCheckedModeBanner: false,
            theme: AppTheme.darkTheme,
            darkTheme: AppTheme.darkTheme,
            supportedLocales: [
              Locale('en', ''),
              Locale('fr', ''),
              Locale('af', ''),
              Locale('de', ''),
              Locale('es', ''),
              Locale('id', ''),
              Locale('pt', ''),
              Locale('tr', ''),
              Locale('hi', '')
            ],
            localizationsDelegates: [
              AppLocalizations.delegate,
              GlobalMaterialLocalizations.delegate,
              GlobalWidgetsLocalizations.delegate
            ],
            localeResolutionCallback: (locale, supportedLocales) {
              return Locale(
                  Provider.of<AppState>(context).selectedLanguageCode);
            },
            locale: Provider.of<AppState>(context).locale,
            themeMode: provider.isDarkTheme ? ThemeMode.dark : ThemeMode.light,
            home: SplashScreen(),
            routes: <String, WidgetBuilder>{
              OnBoardingScreen.tag: (BuildContext context) =>
                  OnBoardingScreen(),
              SignInScreen.tag: (BuildContext context) => SignInScreen(),
              SignUpScreen.tag: (BuildContext context) => SignUpScreen(),
              HomeScreen.tag: (BuildContext context) => HomeScreen(),
              AccountSettingsScreen.tag: (BuildContext context) =>
                  AccountSettingsScreen(),
              HelpScreen.tag: (BuildContext context) => HelpScreen(),
              FaqScreen.tag: (BuildContext context) => FaqScreen(),
              TermsConditionsScreen.tag: (BuildContext context) =>
                  TermsConditionsScreen(),
              EditProfileScreen.tag: (BuildContext context) =>
                  EditProfileScreen(),
            },
            builder: (context, child) {
              return ScrollConfiguration(
                behavior: ScrBehavior(),
                child: child,
              );
            },
          );
        }));
  }
}

class ScrBehavior extends ScrollBehavior {
  @override
  Widget buildViewportChrome(
      BuildContext context, Widget child, AxisDirection axisDirection) {
    return child;
  }
}
