import 'dart:collection';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:streamit_flutter/fragments/home_fragment.dart';
import 'package:streamit_flutter/fragments/more_fragment.dart';
import 'package:streamit_flutter/fragments/my_files_fragment.dart';
import 'package:streamit_flutter/fragments/search_fragment.dart';
import 'package:streamit_flutter/utils/bottom_navigation.dart';
import 'package:streamit_flutter/utils/resources/images.dart';

class HomeScreen extends StatefulWidget {
  static String tag = '/HomeScreen';

  @override
  HomeScreenState createState() => HomeScreenState();
}

class HomeScreenState extends State<HomeScreen> {
  var _selectedIndex = 0;
  var homeFragment = HomeFragment();
  var searchFragment = SearchFragment();
  var myFilesFragment = MyFilesFragment();
  var moreFragment = MoreFragment();
  List<Widget> viewContainer;
  ListQueue<int> _navigationQueue = ListQueue();

  @override
  void initState() {
    super.initState();
    viewContainer = [
      homeFragment,
      searchFragment,
      myFilesFragment,
      moreFragment
    ];
  }

  void _onItemTapped(int index) {
    _navigationQueue.addLast(index);

    setState(() {
      _selectedIndex = index;
    });
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        if (_selectedIndex == 0) return true;
        setState(() {
          _selectedIndex = 0;
          _navigationQueue.removeLast();
        });
        return false;
      },
      child: Scaffold(
        body: viewContainer[_selectedIndex],
        bottomNavigationBar: Container(
          decoration:
              BoxDecoration(color: Theme.of(context).splashColor, boxShadow: [
            BoxShadow(
                color: Colors.grey.withOpacity(0.05),
                offset: Offset.fromDirection(3, 1),
                spreadRadius: 3,
                blurRadius: 5)
          ]),
          child: AppBottomNavigationBar(
            backgroundColor: Theme.of(context).splashColor,
            items: const <AppBottomNavigationBarItem>[
              AppBottomNavigationBarItem(
                icon: ic_home,
              ),
              AppBottomNavigationBarItem(
                icon: ic_search,
              ),
              AppBottomNavigationBarItem(
                icon: ic_folder,
              ),
              AppBottomNavigationBarItem(
                icon: ic_more,
              ),
            ],
            currentIndex: _selectedIndex,
            unselectedIconTheme: IconThemeData(
                color: Theme.of(context).textTheme.headline6.color, size: 22),
            selectedIconTheme:
                IconThemeData(color: Theme.of(context).primaryColor, size: 22),
            onTap: _onItemTapped,
            type: AppBottomNavigationBarType.fixed,
          ),
        ),
      ),
    );
  }
}
