import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:streamit_flutter/screens/home_screen.dart';
import 'package:streamit_flutter/screens/signup.dart';
import 'package:streamit_flutter/utils/app_localizations.dart';
import 'package:streamit_flutter/utils/app_widgets.dart';
import 'package:streamit_flutter/utils/constants.dart';
import 'package:streamit_flutter/utils/resources/images.dart';
import 'package:streamit_flutter/utils/resources/size.dart';
import 'package:streamit_flutter/utils/widget_extensions.dart';

class SignInScreen extends StatefulWidget {
  static String tag = '/SignInScreen';

  @override
  SignInScreenState createState() => SignInScreenState();
}

class SignInScreenState extends State<SignInScreen> {
  FocusNode passFocus = FocusNode();
  FocusNode emailFocus = FocusNode();
  final GlobalKey<FormState> _formKey = GlobalKey<FormState>();
  String email;
  String password;
  bool passwordVisible = false;
  bool isLoading = false;

  showLoading(bool show) {
    setState(() {
      isLoading = show;
    });
  }

  @override
  Widget build(BuildContext context) {
    var form = Form(
      key: _formKey,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          formField(
            context,
            "hint_email",
            maxLine: 1,
            keyboardType: TextInputType.emailAddress,
            validator: (value) {
              return value.validateEMail(context);
            },
            onSaved: (String value) {
              email = value;
            },
            textInputAction: TextInputAction.next,
            focusNode: emailFocus,
            nextFocus: passFocus,
            suffixIcon: Icons.mail_outline,
          ).paddingBottom(spacing_standard_new),
          formField(
            context,
            "hint_password",
            isPassword: true,
            isPasswordVisible: passwordVisible,
            validator: (value) {
              return value.isEmpty
                  ? keyString(context, "error_pwd_requires")
                  : null;
            },
            focusNode: passFocus,
            onSaved: (String value) {
              password = value;
            },
            textInputAction: TextInputAction.done,
            suffixIconSelector: () {
              setState(() {
                passwordVisible = !passwordVisible;
              });
            },
            suffixIcon:
                passwordVisible ? Icons.visibility : Icons.visibility_off,
          )
        ],
      ),
    );
    var signinButton = SizedBox(
      width: double.infinity,
      child: button(context, keyString(context, "login"), () {
        doSignIn(context);
      }),
    );
    var loginWithGoogle = MaterialButton(
      color: Color(0xff2e2f32),
      minWidth: 50,
      height: 40,
      splashColor: Colors.grey.withOpacity(0.2),
      child: Image.asset(ic_google, width: 16, height: 16),
      shape: RoundedRectangleBorder(
        borderRadius: new BorderRadius.circular(spacing_control),
        side: BorderSide(
          width: 0.8,
        ),
      ),
      onPressed: () {},
    ).paddingOnly(left: spacing_standard_new, right: spacing_standard_new);
    var loginWithFb = MaterialButton(
      color: Color(0xff2e2f32),
      minWidth: 50,
      height: 40,
      splashColor: Colors.grey.withOpacity(0.2),
      child: Image.asset(ic_fb, width: 16, height: 16),
      shape: RoundedRectangleBorder(
        borderRadius: new BorderRadius.circular(spacing_control),
        side: BorderSide(
          width: 0.8,
        ),
      ),
      onPressed: () {},
    );

    return Scaffold(
      body: Stack(
        children: <Widget>[
          networkImage("assets/images/background_ek49.png",
              aWidth: double.infinity,
              aHeight: MediaQuery.of(context).size.height * 0.5,
              fit: BoxFit.cover),
          Container(
            height: MediaQuery.of(context).size.height * 0.5,
            decoration: BoxDecoration(
                gradient: new LinearGradient(
                    colors: [
                  Theme.of(context).scaffoldBackgroundColor.withOpacity(0.4),
                  Theme.of(context).scaffoldBackgroundColor,
                ],
                    stops: [
                  0.0,
                  1.0
                ],
                    begin: FractionalOffset.topCenter,
                    end: FractionalOffset.bottomCenter,
                    tileMode: TileMode.repeated)),
          ),
          Container(
            decoration: BoxDecoration(
                gradient: new LinearGradient(
                    colors: [
                  Colors.transparent,
                  Theme.of(context).scaffoldBackgroundColor,
                ],
                    stops: [
                  0.0,
                  1.0
                ],
                    begin: FractionalOffset.topCenter,
                    end: FractionalOffset.bottomCenter,
                    tileMode: TileMode.repeated)),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                text(context, keyString(context, "login"),
                        fontSize: ts_xlarge,
                        textColor: Theme.of(context).textTheme.headline6.color,
                        maxLine: 2,
                        fontFamily: font_bold,
                        isCentered: true)
                    .paddingOnly(
                        top: spacing_control,
                        left: spacing_large,
                        right: spacing_large),
                form.paddingOnly(
                    left: spacing_standard_new,
                    right: spacing_standard_new,
                    top: spacing_large),
                Align(
                  alignment: Alignment.centerRight,
                  child: text(context, keyString(context, "forgot_pswd"),
                          fontSize: ts_medium, textColor: Colors.grey)
                      .paddingAll(spacing_standard_new)
                      .onTap(() {
                    onForgotPasswordClicked(context);
                  }),
                ),
                text(context, keyString(context, "signin_with"),
                        fontSize: ts_medium)
                    .paddingAll(spacing_standard_new),
                Row(
                  children: [
                    loginWithGoogle..paddingOnly(left: spacing_standard_new),
                    loginWithFb
                  ],
                ),
                signinButton.paddingOnly(
                    left: spacing_standard_new,
                    right: spacing_standard_new,
                    top: spacing_large,
                    bottom: spacing_standard_new)
              ],
            ),
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              muviTitle(context).paddingAll(spacing_large),
              text(context, keyString(context, "register"),
                      fontSize: ts_normal,
                      fontFamily: font_medium,
                      textColor: Theme.of(context).primaryColor)
                  .paddingAll(spacing_control)
                  .onTap(() {
                launchScreen(context, SignUpScreen.tag);
              })
            ],
          ),
          Center(child: loadingWidgetMaker().visible(isLoading))
        ],
      ),
    );
  }

  onForgotPasswordClicked(context) {}

  doSignIn(context) {
    launchScreenWithNewTask(context, HomeScreen.tag);
  }
}
