import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:streamit_flutter/screens/home_screen.dart';
import 'package:streamit_flutter/utils/app_localizations.dart';
import 'package:streamit_flutter/utils/app_widgets.dart';
import 'package:streamit_flutter/utils/constants.dart';
import 'package:streamit_flutter/utils/resources/images.dart';
import 'package:streamit_flutter/utils/resources/size.dart';
import 'package:streamit_flutter/utils/widget_extensions.dart';

class SignUpScreen extends StatefulWidget {
  static String tag = '/SignUpScreen';

  @override
  SignUpScreenState createState() => SignUpScreenState();
}

class SignUpScreenState extends State<SignUpScreen> {
  FocusNode passFocus = FocusNode();
  FocusNode emailFocus = FocusNode();
  FocusNode confirmPasswordFocus = FocusNode();
  TextEditingController _controller = TextEditingController();
  final GlobalKey<FormState> _formKey = GlobalKey<FormState>();
  String email;
  String password;
  bool passwordVisible = false;
  bool isLoading = false;

  showLoading(bool show) {
    setState(() {
      isLoading = show;
    });
  }

  @override
  Widget build(BuildContext context) {
    var form = Form(
      key: _formKey,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          TextFormField(
            cursorColor: Theme.of(context).primaryColor,
            maxLines: 1,
            keyboardType: TextInputType.emailAddress,
            validator: (value) {
              return value.validateEMail(context);
            },
            onSaved: (String value) {
              email = value;
            },
            textInputAction: TextInputAction.next,
            focusNode: emailFocus,
            onFieldSubmitted: (arg) {
              FocusScope.of(context).requestFocus(passFocus);
            },
            decoration: InputDecoration(
              focusedBorder: UnderlineInputBorder(
                borderSide: BorderSide(color: Theme.of(context).primaryColor),
              ),
              enabledBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    color: Theme.of(context).textTheme.headline6.color),
              ),
              labelText: keyString(context, "hint_email"),
              labelStyle: TextStyle(
                  fontSize: ts_normal,
                  color: Theme.of(context).textTheme.headline6.color),
              suffixIcon: Icon(
                Icons.mail_outline,
                color: Theme.of(context).primaryColor,
                size: 20,
              ),
              contentPadding: new EdgeInsets.only(bottom: 1.5),
            ),
            style: TextStyle(
                fontSize: ts_normal,
                color: Theme.of(context).textTheme.headline6.color,
                fontFamily: font_regular),
          ).paddingBottom(spacing_standard_new),
          TextFormField(
            controller: _controller,
            obscureText: passwordVisible,
            cursorColor: Theme.of(context).primaryColor,
            style: TextStyle(
                fontSize: ts_normal,
                color: Theme.of(context).textTheme.headline6.color,
                fontFamily: font_regular),
            validator: (value) {
              return value.isEmpty
                  ? keyString(context, "error_pwd_requires")
                  : null;
            },
            focusNode: passFocus,
            onSaved: (String value) {
              password = value;
            },
            textInputAction: TextInputAction.done,
            decoration: new InputDecoration(
                focusedBorder: UnderlineInputBorder(
                  borderSide: BorderSide(color: Theme.of(context).primaryColor),
                ),
                enabledBorder: UnderlineInputBorder(
                  borderSide: BorderSide(
                      color: Theme.of(context).textTheme.headline6.color),
                ),
                labelText: keyString(context, "hint_password"),
                labelStyle: TextStyle(
                    fontSize: ts_normal,
                    color: Theme.of(context).textTheme.headline6.color),
                contentPadding: new EdgeInsets.only(bottom: 1.5),
                suffixIcon: new GestureDetector(
                  onTap: () {
                    setState(() {
                      passwordVisible = !passwordVisible;
                    });
                  },
                  child: new Icon(
                    passwordVisible ? Icons.visibility : Icons.visibility_off,
                    color: Theme.of(context).primaryColor,
                    size: 20,
                  ),
                )),
          ).paddingBottom(spacing_standard_new),
          TextFormField(
              obscureText: passwordVisible,
              cursorColor: Theme.of(context).primaryColor,
              style: TextStyle(
                  fontSize: ts_normal,
                  color: Theme.of(context).textTheme.headline6.color,
                  fontFamily: font_regular),
              focusNode: confirmPasswordFocus,
              validator: (value) {
                if (value.isEmpty) {
                  return keyString(context, "error_confirm_password_required");
                }
                return _controller.text == value
                    ? null
                    : keyString(context, "error_password_not_match");
              },
              textInputAction: TextInputAction.next,
              onFieldSubmitted: (arg) {
                FocusScope.of(context).requestFocus(passFocus);
              },
              decoration: new InputDecoration(
                focusedBorder: UnderlineInputBorder(
                  borderSide: BorderSide(color: Theme.of(context).primaryColor),
                ),
                enabledBorder: UnderlineInputBorder(
                  borderSide: BorderSide(
                      color: Theme.of(context).textTheme.headline6.color),
                ),
                labelText: keyString(context, "hint_confirm_password"),
                labelStyle: TextStyle(
                    fontSize: ts_normal,
                    color: Theme.of(context).textTheme.headline6.color),
                contentPadding:
                    EdgeInsets.only(bottom: 1.5, top: spacing_control),
                suffixIcon: new GestureDetector(
                  onTap: () {
                    setState(() {
                      passwordVisible = !passwordVisible;
                    });
                  },
                  child: new Icon(
                    passwordVisible ? Icons.visibility : Icons.visibility_off,
                    color: Theme.of(context).primaryColor,
                    size: 20,
                  ),
                ),
              )),
        ],
      ),
    );
    var signUpButton = SizedBox(
      width: double.infinity,
      child: button(context, keyString(context, "sign_up"), () {
        final form = _formKey.currentState;
        if (form.validate()) {
          form.save();
          doSignUp(context);
        }
      }),
    );

    var loginWithGoogle = MaterialButton(
      color: Color(0xff2e2f32),
      minWidth: 50,
      height: 40,
      splashColor: Colors.grey.withOpacity(0.2),
      child: Image.asset(ic_google, width: 16, height: 16),
      shape: RoundedRectangleBorder(
        borderRadius: new BorderRadius.circular(spacing_control),
        side: BorderSide(
          width: 0.8,
        ),
      ),
      onPressed: () {},
    ).paddingOnly(left: spacing_standard_new, right: spacing_standard_new);
    var loginWithFb = MaterialButton(
      color: Color(0xff2e2f32),
      minWidth: 50,
      height: 40,
      splashColor: Colors.grey.withOpacity(0.2),
      child: Image.asset(ic_fb, width: 16, height: 16),
      shape: RoundedRectangleBorder(
        borderRadius: new BorderRadius.circular(spacing_control),
        side: BorderSide(
          width: 0.8,
        ),
      ),
      onPressed: () {},
    );
    return Scaffold(
      appBar: appBarLayout(context, "", darkBackground: false),
      body: Stack(
        children: <Widget>[
          SingleChildScrollView(
            child: Column(
              mainAxisSize: MainAxisSize.max,
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                text(context, "Create Account",
                        fontSize: ts_xlarge,
                        textColor: Theme.of(context).textTheme.headline6.color,
                        maxLine: 2,
                        fontFamily: font_bold,
                        isCentered: true)
                    .paddingOnly(
                        top: spacing_standard_new,
                        left: spacing_standard_new,
                        right: spacing_standard_new),
                text(
                  context,
                  keyString(context, "register_desc"),
                  fontSize: ts_normal,
                  textColor: Theme.of(context).textTheme.subtitle2.color,
                  maxLine: 2,
                ).paddingOnly(
                    top: spacing_control,
                    left: spacing_standard_new,
                    right: spacing_standard_new),
                form.paddingOnly(
                    left: spacing_standard_new,
                    right: spacing_standard_new,
                    top: spacing_large,
                    bottom: spacing_standard_new),
                text(context, keyString(context, "signup_with"),
                        fontSize: ts_medium)
                    .paddingAll(spacing_standard_new),
                Row(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    loginWithGoogle..paddingOnly(left: spacing_standard_new),
                    loginWithFb
                  ],
                ),
              ],
            ),
          ),
          Align(
            alignment: Alignment.bottomCenter,
            child: signUpButton.paddingOnly(
                left: spacing_standard_new,
                right: spacing_standard_new,
                top: spacing_large,
                bottom: spacing_standard_new),
          ),
          Center(child: loadingWidgetMaker().visible(isLoading))
        ],
      ),
    );
  }

  onForgotPasswordClicked(context) {}

  doSignUp(context) {
    launchScreenWithNewTask(context, HomeScreen.tag);
  }
}
