<?php


function stValidationToken () {
	$data = [
		'message' => 'Valid token',
        'status' => true,
	];
	$response = collect((new Jwt_Auth_Public('jwt-auth', '1.1.0'))->validate_token(false));
   
	if ($response->has('errors')) {
		$data['status'] = false;
		$data['message'] = isset(array_values($response['errors'])[0][0]) ? array_values($response['errors'])[0][0] : __("Authorization failed");
	}else {
        $data['user_id'] = $response['data']->user->id;
    }
	return $data;
}

function stValidateRequest($rules, $request, $message = [])
{
	$error_messages = [];
	$required_message = ' field is required';
	$email_message =  ' has invalid email address';

	if (count($rules)) {
		foreach ($rules as $key => $rule) {
			if (strpos($rule, '|') !== false) {
				$ruleArray = explode('|', $rule);
				foreach ($ruleArray as $r) {
					if ($r === 'required') {
						if (!isset($request[$key]) || $request[$key] === "" || $request[$key] === null) {
							$error_messages[] = isset($message[$key]) ? $message[$key] : str_replace('_', ' ', $key) . $required_message;
						}
					} elseif ($r === 'email') {
						if (isset($request[$key])) {
							if (!filter_var($request[$key], FILTER_VALIDATE_EMAIL)) {
								$error_messages[] = isset($message[$key]) ? $message[$key] : str_replace('_', ' ', $key) . $email_message;
							}
						}
					}
				}
			} else {
				if ($rule === 'required') {
					if (!isset($request[$key]) || $request[$key] === "" || $request[$key] === null) {
						$error_messages[] = isset($message[$key]) ? $message[$key] : str_replace('_', ' ', $key) . $required_message;
					}
				} elseif ($r === 'email') {
					if (isset($request[$key])) {
						if (!filter_var($request[$key], FILTER_VALIDATE_EMAIL)) {
							$error_messages[] = isset($message[$key]) ? $message[$key] : str_replace('_', ' ', $key) . $email_message;
						}
					}
				}
			}

		}
	}

	return $error_messages;
}


function stRecursiveSanitizeTextField($array)
{
	$filterParameters = [];
	foreach ($array as $key => $value) {

		if ($value === '') {
			$filterParameters[$key] = null;
		} else {
			if (is_array($value)) {
				$filterParameters[$key] = stRecursiveSanitizeTextField($value);
			} else {
				if (preg_match("/<[^<]+>/", $value, $m) !== 0) {
					$filterParameters[$key] = $value;
				} else {
					$filterParameters[$key] = sanitize_text_field($value);
				}
			}
		}

	}

	return $filterParameters;
}

function stGetErrorMessage ($response) {
	return isset(array_values($response->errors)[0][0]) ? array_values($response->errors)[0][0] : __("Internal server error");
}

function stGenerateString($length_of_string = 10)
{
	// String of all alphanumeric character
	$str_result = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
	return substr(str_shuffle($str_result),0, $length_of_string);
}

function comman_message_response( $message, $status_code = 200)
{
    $response = new WP_REST_Response(array(
            "message" => $message
        )
    );
    $response->set_status($status_code);
    return $response;
}

function comman_custom_response( $res, $status_code = 200 )
{
    $response = new WP_REST_Response($res);
    $response->set_status($status_code);
    return $response;
}

function comman_list_response( $data )
{
    $response = new WP_REST_Response(array(
        "data" => $data
    ));

    $response->set_status(200);
    return $response;
}

function get_random_password($n = 10) {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $randomString = '';

    for ($i = 0; $i < $n; $i++) {
        $index = rand(0, strlen($characters) - 1);
        $randomString .= $characters[$index];
    }

    return $randomString;
}

function streamit_movie_video_detail_helper($id,$user_id = null){
    
    $list = get_post($id);

    if( empty($list) && $list === null) {
        return [];
    }
    $post_meta     = get_post_meta($id);
    $avg_rating    = $post_meta['_masvideos_average_rating'][0];
    
    $image = wp_get_attachment_image_src(get_post_thumbnail_id($list->ID), [300, 300]);
    $temp = [
        'id'                => $list->ID,
        'title'             => get_the_title($id),
        'image'             => !empty($image) ? $image[0] : null,
        'description'       => wp_strip_all_tags(get_the_content($id)),
        'excerpt'           => wp_strip_all_tags(get_the_excerpt($list)),
        'is_featured'       => !empty($post_meta['__featured'][0]) && $post_meta['__featured'][0] === 'yes' ? true : false,
        // 'image'             => streamit_get_movie_video_images_helper($list),
        'likes'             => wp_ulike_get_post_likes($list->ID),
        'post_type'         => $list->post_type,
        'name_upcoming'     => isset($post_meta['name_upcoming']) ? $post_meta['name_upcoming'][0] : null
    ];

    if($user_id !== null){
        $temp['is_liked']       = streamit_user_liked_post($list->ID,$user_id);
        $temp['is_watchlist']   = streamit_watchlist($list->ID,$user_id);
    } else {
        $temp['is_liked']       = null;
        $temp['is_watchlist']   = null;
    }
    if( $list->post_type === 'movie' ) {
        $temp['avg_rating']        = ($avg_rating === null ? 0 : $avg_rating );

        // $temp['attachment']        = wp_get_attachment_link($id);
        $temp['publish_date']      = $list->post_date;
        $temp['publish_date_gmt']  = $list->post_date_gmt;
        $temp['embed_content']     = $post_meta['_movie_embed_content'][0];
        $temp['movie_choice']      = $post_meta['_movie_choice'][0];
        $movie_file = null;
        if ( $temp['movie_choice'] == 'movie_file' ) {
            $movie_file = isset($post_meta['_movie_attachment_id']) ? wp_get_attachment_url($post_meta['_movie_attachment_id'][0]) : null;
        }
        $temp['movie_file'] = $movie_file;
        $temp['url_link']          = $post_meta['_movie_url_link'][0];
        $movie_file = null;
        if ( $temp['movie_choice'] == 'movie_file' ) {
            $movie_file = isset($post_meta['_movie_attachment_id']) ? wp_get_attachment_url($post_meta['_movie_attachment_id'][0]) : null;
        }
        $temp['movie_file'] = $movie_file;
        $temp['tag']               = get_taxonomy_terms_helper($list , 'movie','tag');
        $temp['genre']             = get_taxonomy_terms_helper($list , 'movie','genre');
        $temp['visibility']        = get_taxonomy_terms_helper($list , 'movie','visibility');
        $temp['run_time']          = $post_meta['_movie_run_time'][0];
        $temp['censor_rating']     = $post_meta['_movie_censor_rating'][0];
        // $temp['cast']              = ($post_meta['_cast'] != null) ? $post_meta['_cast'][0] : null;
        $temp['release_date']      = date_i18n(get_option( 'date_format'),$post_meta['_movie_release_date'][0]);

        $logo = isset($post_meta['name_logo']) ? wp_get_attachment_image_src($post_meta['name_logo'][0],[300, 300]) : null;

        if (!(empty($logo))) {
            $temp['logo'] = $logo[0];
        } else {
            $temp['logo'] = null;
        }

        $award_image = isset($post_meta['name_award']) ? wp_get_attachment_image_src($post_meta['name_award'][0],[300, 300]) : null;
        if (!(empty($award_image))) {
            $temp['award_image'] = $award_image[0];
        } else {
            $temp['award_image'] = null;
        }
        $temp['trailer_link'] =  isset($post_meta['name_trailer_link']) ? $post_meta['name_trailer_link'][0] : null;
        $temp['award_description'] = isset($post_meta['name_award_desc']) ? $post_meta['name_award_desc'][0] : null;
    }

    if( $list->post_type === 'tv_show' ) {
        $temp['avg_rating']        = ($avg_rating === null ? 0 : $avg_rating );

        // $temp['attachment']        = wp_get_attachment_link($id);
        $temp['publish_date']      = $list->post_date;
        $temp['publish_date_gmt']  = $list->post_date_gmt;
        $tv_show_season = get_post_meta($id, '_seasons');
        $show_seasons = $tv_show_season[0];        
        $temp['total_seasons'] = !empty($show_seasons) ? count($show_seasons) : 0;
        $temp['tag']           = get_taxonomy_terms_helper($list , 'tv_show','tag');
        $temp['genre']         = get_taxonomy_terms_helper($list , 'tv_show','genre');
        $temp['visibility']    = get_taxonomy_terms_helper($list , 'tv_show','visibility');
    }

    if( $list->post_type === 'episode' ){
        $temp['tv_show_id'] = $post_meta['_tv_show_id'][0];
        $temp['embed_content']  = $post_meta['_episode_embed_content'][0];
        $temp['episode_choice'] = $post_meta['_episode_choice'][0];
        $episode_file = null;
        if ( $temp['episode_choice'] == 'episode_file' ) {
            $episode_file = isset($post_meta['_episode_attachment_id']) ? wp_get_attachment_url($post_meta['_episode_attachment_id'][0]) : null;
        }
        $temp['episode_file'] = $episode_file;
        $temp['url_link']     = $post_meta['_episode_url_link'][0];
        $temp['episode_number'] = $post_meta['_episode_number'][0];
        $temp['run_time']   = $post_meta['_episode_run_time'][0];
        $temp['release_date']      = date_i18n(get_option( 'date_format'),$post_meta['_episode_release_date'][0]);
    }

    return $temp;
}

function streamit_get_movie_video_images_helper($post = null, $user_id = null)
{
	$images = array();
	$full_image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), "full");

	// print_r($full_image);
    if (!(empty($full_image)) && $full_image[0]) {
        $images['image'] = $full_image[0];
    } else {
        $images['image'] = '';
    }
    $images['ID'] = $post->ID;
    $images['image'] = $full_image[0];
    $images['post_title'] = get_the_title();
    $images['post_content'] = esc_html(get_the_content());
    $images['post_excerpt'] = esc_html(get_the_excerpt());
    $images['post_date'] = $post->post_date;
    $images['post_date_gmt'] = $post->post_date_gmt;
    $images['readable_date'] = get_the_date();
    $images['share_url'] = get_the_permalink();
    $images['no_of_comments'] = get_comments_number();

	return $images;
}

function streamit_post_args($params = null, $filter = null, $post_in = null)
{
    $args['post_type'] = array('movie','tv_show', 'episode' ); //(!empty($params['post_type']) && isset($params['post_type'])) ? $params['post_type'] : 'movie';
    $args['post_status'] = 'publish';
    $args['posts_per_page'] = (!empty($params['posts_per_page']) && isset($params['posts_per_page'])) ? $params['posts_per_page'] : 20;
    $args['paged'] =  (!empty($params['paged']) && isset($params['paged'])) ? $params['paged'] : 1;
    $args['streamit_title_filter'] = ($params['search']) && !empty($params['search']) ? $params['search'] : null;

    if ($post_in) {
        $args['post__in'] = $post_in;
    }

    if ($filter === 'recent') {
        $args['order'] = 'DESC';
        $args['orderby'] = 'ID';
    }

    return $args;
}

function get_taxonomy_terms_helper( $list, $type , $taxonomy = 'cat' ) {
	$terms = array();

	foreach ( wp_get_object_terms( $list->ID, $type.'_'. $taxonomy ) as $term ) {
		$terms[] = array(
			'id'   => $term->term_id,
			'name' => $term->name,
			'slug' => $term->slug,
		);
	}

	return $terms;
}

function get_movie_show_episode_list ($id,$num_pages = '',$i='',$user_id = null) {

    $list = get_post($id);
    if( empty($list) && $list === null) {
        return [];
    }
    $post_meta     = get_post_meta($id);
    $avg_rating    = (!empty($post_meta['_masvideos_average_rating'])) ? $post_meta['_masvideos_average_rating'][0] : 0;
    $image = wp_get_attachment_image_src(get_post_thumbnail_id($id), [300, 300]);
    $temp = [
        'id'                => $list->ID,
        'title'             => get_the_title($id),
        'image'             => !empty($image) ? $image[0] : null,
        'description'       => wp_strip_all_tags(get_the_content($id)),
        'excerpt'           => wp_strip_all_tags(get_the_excerpt($list)),
        'is_featured'       => !empty($post_meta['__featured'][0]) && $post_meta['__featured'][0] === 'yes' ? true : false,
        'post_type'         => $list->post_type,
        'likes'             => wp_ulike_get_post_likes($list->ID),
    ];

    if($user_id != null){
        $temp['is_liked']       = streamit_user_liked_post($id,$user_id);
        $temp['is_watchlist']   = streamit_watchlist($id,$user_id);
    } else {
        $temp['is_liked']       = null;
        $temp['is_watchlist']   = null;
    }

    if( $list->post_type === 'movie' ){
        $temp['tag']        = get_taxonomy_terms_helper($list , 'movie','tag');
        $temp['genre']      = get_taxonomy_terms_helper($list , 'movie','genre');
        $temp['avg_rating'] = ($avg_rating === null ? 0 : $avg_rating );
        $temp['censor_rating']     = $post_meta['_movie_censor_rating'][0];
    }

    if( $list->post_type === 'tv_show' ){
        $temp['tag']        = get_taxonomy_terms_helper($list , 'tv_show','tag');
        $temp['genre']      = get_taxonomy_terms_helper($list , 'tv_show','genre');
        $temp['avg_rating'] = ($avg_rating === null ? 0 : $avg_rating );
    }

    return $temp;
}

function streamit_watchlist($post_id,$user_id) {

    $watchlist = get_user_meta( $user_id, '_user_watchlist', true );
    
    $watchlist_array = explode(', ', $watchlist);
    
    return in_array($post_id,$watchlist_array);
}

function streamit_user_liked_post($post_id,$user_id) {
    global $wpdb;
    $table_name = $wpdb->prefix.'ulike';

    $liked_post = $wpdb->get_row("SELECT * FROM {$table_name} WHERE `user_id`=" . $user_id . " AND `post_id` =" . $post_id . " AND `status`='like' ", OBJECT);

    return ($liked_post != null && $liked_post->status == 'like') ? 'like' : 'unlike';
}

function streamit_get_taxonomy ( $taxonomy , $terms ) {
    $data = [];
    if( count($terms) > 0 ){
        $data = [
            'taxonomy' => $taxonomy,
            'field' => 'term_id',
            'operator' => 'IN',
            'terms' => $terms,
        ];
    }
    return $data;
}
function streamit_title_filter( $where, $wp_query ){
    global $wpdb;
    if( $search_term = $wp_query->get( 'streamit_title_filter' ) ) :
        $search_term = $wpdb->esc_like( $search_term );
        $search_term = ' \'%' . $search_term . '%\'';
        $title_filter_relation = ( strtoupper( $wp_query->get( 'title_filter_relation' ) ) == 'OR' ? 'OR' : 'AND' );
        $where .= ' '.$title_filter_relation.' ' . $wpdb->posts . '.post_title LIKE ' . $search_term;
    endif;
    return $where;
}

add_filter( 'posts_where', 'streamit_title_filter', 10, 2 );